package com.srs.comprehensive.service;

import java.util.List;
import com.srs.comprehensive.domain.SrsBonusRules;

/**
 * 加分规则Service接口
 * 
 * @author srs
 * @date 2023-06-19
 */
public interface IStsBonusRulesService 
{
    /**
     * 查询加分规则
     * 
     * @param id 加分规则主键
     * @return 加分规则
     */
    public SrsBonusRules selectStsBonusRulesById(Long id);

    /**
     * 查询加分规则列表
     * 
     * @param srsBonusRules 加分规则
     * @return 加分规则集合
     */
    public List<SrsBonusRules> selectStsBonusRulesList(SrsBonusRules srsBonusRules);

    /**
     * 新增加分规则
     * 
     * @param srsBonusRules 加分规则
     * @return 结果
     */
    public int insertStsBonusRules(SrsBonusRules srsBonusRules);

    /**
     * 修改加分规则
     * 
     * @param srsBonusRules 加分规则
     * @return 结果
     */
    public int updateStsBonusRules(SrsBonusRules srsBonusRules);

    /**
     * 批量删除加分规则
     * 
     * @param ids 需要删除的加分规则主键集合
     * @return 结果
     */
    public int deleteStsBonusRulesByIds(Long[] ids);

    /**
     * 删除加分规则信息
     * 
     * @param id 加分规则主键
     * @return 结果
     */
    public int deleteStsBonusRulesById(Long id);
}
